pub struct DenomArray<const NUM_PRIMES: usize> { /* private fields */ }Expand description
Denominator representation that decomposes an integer as a product of the
first NUM_PRIMES primes, multiplied by a regular big integer when that’s
not sufficient.